@@ -1,6 +1,6 @@
 # encoding=UTF-8
 
-# Copyright © 2008, 2009, 2010, 2011, 2012, 2013 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2008-2015 Jakub Wilk <jwilk@jwilk.net>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -11,7 +11,7 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 # General Public License for more details.
 
-from __future__ import with_statement
+from __future__ import print_function
 
 import argparse
 import contextlib
@@ -49,7 +49,7 @@ class Saver(object):
 
     @utils.not_overridden
     def save(self, document, pages, djvu_path, sed_file):
-        raise NotImplementedError('Cannot save results in this format')
+        raise NotImplementedError('Cannot save results in this format')  # <no-coverage>
 
 class BundledSaver(Saver):
 
@@ -117,17 +117,6 @@ class DryRunSaver(Saver):
     def save(self, document, pages, djvu_path, sed_file):
         pass
 
-def get_cpu_count():
-    try:
-        import multiprocessing
-        return multiprocessing.cpu_count()
-    except (ImportError, NotImplementedError):
-        pass
-    try:
-        return os.sysconf('SC_NPROCESSORS_ONLN')
-    except (ValueError, OSError, AttributeError):
-        return 1
-
 def expand_template(template, pageno, pageid):
     d = {
         'page': pageno,
@@ -163,7 +152,7 @@ class ArgumentParser(argparse.ArgumentParser):
 
     savers = BundledSaver, IndirectSaver, ScriptSaver, InPlaceSaver, DryRunSaver
     engines = list(engines.get_engines())
-    [default_engine] = [engine for engine in engines if engine.name == 'ocropus']
+    [default_engine] = [engine for engine in engines if engine.name == 'tesseract']
 
     _details_map = dict(
         lines=text_zones.TEXT_DETAILS_LINE,
@@ -206,12 +195,14 @@ class ArgumentParser(argparse.ArgumentParser):
         group.add_argument('--clear-text', dest='clear_text', action='store_true', default=False, help='remove existing hidden text')
         group.add_argument('--save-raw-ocr', dest='save_raw_ocr_dir', metavar='DIRECTORY', help='save raw OCR output')
         group.add_argument('--raw-ocr-filename-template', metavar='TEMPLATE', default='{id-ext}', help='file naming scheme for raw OCR')
-        self.add_argument('-e', '--engine', dest='engine', nargs=1, action=self.set_engine, default=self.default_engine, help='OCR engine to use')
+        self.add_argument('-e', '--engine', dest='engine', nargs=1, action=self.set_engine, default=self.default_engine, help='OCR engine to use (default: {0})'.format(self.default_engine.name))
         self.add_argument('--list-engines', action=self.list_engines, nargs=0, help='print list of available OCR engines')
         self.add_argument('-l', '--language', dest='language', help='set recognition language')
         self.add_argument('--list-languages', action=self.list_languages, nargs=0, help='print list of available languages')
         self.add_argument('--render', dest='render_layers', choices=self._render_map.keys(), action='store', default='mask', help='image layers to render')
-        self.add_argument('-p', '--pages', dest='pages', action='store', default=None, help='pages to process')
+        def pages(x):
+            return utils.parse_page_numbers(x)
+        self.add_argument('-p', '--pages', dest='pages', action='store', default=None, type=pages, help='pages to process')
         self.add_argument('-j', '--jobs', dest='n_jobs', metavar='N', nargs='?', type=int, default=1, help='number of jobs to run simultaneously')
         self.add_argument('path', metavar='FILE', help='DjVu file to process')
         group = self.add_argument_group(title='text segmentation options')
@@ -242,20 +233,20 @@ class ArgumentParser(argparse.ArgumentParser):
                 except errors.EngineNotFound:
                     pass
                 else:
-                    print engine.name
+                    print(engine.name)
             sys.exit(0)
 
     class list_languages(argparse.Action):
         def __call__(self, parser, namespace, values, option_string=None):
             try:
                 for language in sorted(namespace.engine().list_languages()):
-                    print language
-            except errors.EngineNotFound, ex:
+                    print(language)
+            except errors.EngineNotFound as ex:
                 logger.error(ex)
-                sys.exit(1)
-            except errors.UnknownLanguageList, ex:
+                sys.exit(errors.EXIT_FATAL)
+            except errors.UnknownLanguageList as ex:
                 logger.error(ex)
-                sys.exit(1)
+                sys.exit(errors.EXIT_FATAL)
             else:
                 sys.exit(0)
 
@@ -273,10 +264,6 @@ class ArgumentParser(argparse.ArgumentParser):
 
     def parse_args(self, args=None, namespace=None):
         options = argparse.ArgumentParser.parse_args(self, args, namespace)
-        try:
-            options.pages = utils.parse_page_numbers(options.pages)
-        except (TypeError, ValueError):
-            self.error('Unable to parse page numbers')
         options.details = self._details_map[options.details]
         options.render_layers = self._render_map[options.render_layers]
         options.resume_on_error = options.on_error == 'resume'
@@ -292,13 +279,13 @@ class ArgumentParser(argparse.ArgumentParser):
         if options.save_raw_ocr_dir is not None:
             try:
                 os.stat(os.path.join(options.save_raw_ocr_dir, ''))
-            except EnvironmentError, ex:
+            except EnvironmentError as ex:
                 self.error('cannot open %r: %s' % (ex.filename, ex[1]))
             try:
                 expand_template(options.raw_ocr_filename_template, pageno=0, pageid='')
-            except ValueError, ex:
+            except ValueError as ex:
                 self.error('cannot parse filename template %r: %s' % (options.raw_ocr_filename_template, ex))
-            except KeyError, ex:
+            except KeyError as ex:
                 self.error('cannot parse filename template %r: unknown field %r' % (options.raw_ocr_filename_template, ex.args[0]))
         # It might be tempting to verify language name correctness at argument
         # parse time (rather than after argument parsing). However, it's
@@ -316,24 +303,32 @@ class ArgumentParser(argparse.ArgumentParser):
             kwargs[key] = value
         try:
             options.engine = options.engine(**kwargs)
-        except AttributeError, ex:
+        except AttributeError as ex:
             self.error(str(ex))
-        except errors.EngineNotFound, ex:
+        except errors.EngineNotFound as ex:
             self.error(str(ex))
         try:
             options.engine.check_language(options.language)
-        except errors.MissingLanguagePack, ex:
+        except errors.MissingLanguagePack as ex:
             self.error(str(ex))
-        except errors.InvalidLanguageId, ex:
+        except errors.InvalidLanguageId as ex:
             self.error(str(ex))
         except errors.UnknownLanguageList:
             # For now, let's assume the language pack is installed.
             pass
         options.uax29 = options.language if options.word_segmentation == 'uax29' else None
         if options.n_jobs is None:
-            options.n_jobs = get_cpu_count()
+            options.n_jobs = utils.get_cpu_count()
+        elif options.n_jobs < 1:
+            options.n_jobs = 1
         return options
 
+class Results(dict):
+    seen_exception = False
+
+    def __missing__(self, key):
+        return
+
 class Context(djvu.decode.Context):
 
     def init(self, options):
@@ -418,11 +413,11 @@ class Context(djvu.decode.Context):
             except djvu.decode.NotAvailable:
                 logger.info('No image suitable for OCR.')
                 result = False
-            except (SystemExit, KeyboardInterrupt), ex:
+            except (SystemExit, KeyboardInterrupt) as ex:
                 with condition:
                     condition.notify()
                 raise
-            except Exception, ex:
+            except Exception as ex:
                 try:
                     interrupted_by_user = isinstance(ex, ipc.CalledProcessInterrupted) and ex.by_user
                     message = 'Exception while processing page %d:\n%s' % (n + 1, traceback.format_exc())
@@ -430,6 +425,7 @@ class Context(djvu.decode.Context):
                     if self._options.resume_on_error and not interrupted_by_user:
                         # As requested by user, don't abort on error and pretend that nothing happened.
                         results[n] = False
+                        results.seen_exception = True
                         continue
                     else:
                         # The main thread will take care of aborting the application.
@@ -452,7 +448,7 @@ class Context(djvu.decode.Context):
             pages = list(document.pages)
         else:
             pages = [document.pages[i - 1] for i in pages]
-        results = dict((page.n, None) for page in pages)
+        results = Results()
         condition = threading.Condition()
         threads = [
             threading.Thread(target=self.page_thread, args=(pages, results, condition))
@@ -497,12 +493,12 @@ class Context(djvu.decode.Context):
                     for thread in threads:
                         thread.join()
                     self._debug = True
-                    sys.exit(1)
+                    sys.exit(errors.EXIT_FATAL)
                 if result is False:
                     # No image suitable for OCR.
                     pass
                 else:
-                    result.print_into(sed_file)
+                    text_zones.print_sexpr(result, sed_file)
                 sed_file.write('\n.\n\n')
             sed_file.flush()
             saver = self._options.saver
@@ -518,6 +514,8 @@ class Context(djvu.decode.Context):
             raise
         finally:
             sed_file.close()
+        if results.seen_exception:
+            sys.exit(errors.EXIT_NONFATAL)
 
     def process(self, *args, **kwargs):
         try:
@@ -542,10 +540,10 @@ def main(argv=sys.argv):
         context.process(options.path, options.pages)
     except KeyboardInterrupt:
         logger.info('Interrupted by user.')
-        sys.exit(1)
+        sys.exit(errors.EXIT_FATAL)
     finally:
         temp_dir = context.close()
         if temp_dir is not None:
             logger.info('Intermediate files were left in the %r directory.' % temp_dir)
 
-# vim:ts=4 sw=4 et
+# vim:ts=4 sts=4 sw=4 et
