@@ -1,6 +1,6 @@
 # encoding=UTF-8
 
-# Copyright © 2008, 2009, 2010, 2011, 2012, 2013 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2008-2015 Jakub Wilk <jwilk@jwilk.net>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -25,7 +25,7 @@ from . import utils
 
 try:
     from lxml import etree
-except ImportError, ex:
+except ImportError as ex:
     utils.enhance_import_error(ex, 'lxml', 'python-lxml', 'http://lxml.de/')
     raise
 
@@ -40,8 +40,7 @@ TEXT_DETAILS_LINE = const.TEXT_ZONE_LINE
 TEXT_DETAILS_WORD = const.TEXT_ZONE_WORD
 TEXT_DETAILS_CHARACTER = const.TEXT_ZONE_CHARACTER
 
-hocr_class_to_djvu = \
-dict(
+hocr_class_to_djvu = dict(
     ocr_page=const.TEXT_ZONE_PAGE,
     ocr_column=const.TEXT_ZONE_COLUMN,
     ocr_carea=const.TEXT_ZONE_COLUMN,
@@ -53,8 +52,7 @@ dict(
     ocrx_word=const.TEXT_ZONE_WORD
 ).get
 
-cuneiform_tag_to_djvu = \
-dict(
+cuneiform_tag_to_djvu = dict(
     body=const.TEXT_ZONE_PAGE,
     p=const.TEXT_ZONE_PARAGRAPH,
     span=const.TEXT_ZONE_CHARACTER,
@@ -139,6 +137,7 @@ def _apply_bboxes(djvu_class, bbox_source, text, settings, page_size):
                 (x0, y0, x1, y1) = bbox
                 (w, h) = page_size
                 bbox = (x0, h - y1, x1, h - y0)
+                del x0, y0, x1, y1  # quieten pyflakes
             coordinates += [bbox]
     if len(coordinates) == len(text):
         pass  # OK
@@ -169,9 +168,9 @@ def _apply_bboxes(djvu_class, bbox_source, text, settings, page_size):
                     raise errors.MalformedHocr("missing bbox for non-whitespace character")
                 bbox.update(text_zones.BBox(*coordinates[k]))
             last_word = text_zones.Zone(type=const.TEXT_ZONE_WORD, bbox=bbox)
-            words += last_word,
+            words += [last_word]
             if settings.details > TEXT_DETAILS_CHARACTER:
-                last_word += subtext,
+                last_word += [subtext]
             else:
                 last_word += [
                     text_zones.Zone(type=const.TEXT_ZONE_CHARACTER, bbox=(x0, y0, x1, y1), children=[ch])
@@ -215,7 +214,7 @@ def _scan(node, settings, page_size=None):
         )
 
     if settings.cuneiform and settings.cuneiform <= (0, 8):
-        # Cuneiform ≤ 0.8 don't mark OCR elements in an hOCR way.
+        # Cuneiform ≤ 0.8 doesn't mark OCR elements in an hOCR way.
         djvu_class = cuneiform_tag_to_djvu(node.tag)
     else:
         hocr_classes = (node.get('class') or '').split()
@@ -231,7 +230,7 @@ def _scan(node, settings, page_size=None):
                 break
         else:
             if node.tag == 'p':
-                # Cuneiform ≥ 0.9 don't mark paragraphs in an hOCR way.
+                # Cuneiform ≥ 0.9 doesn't mark paragraphs in an hOCR way.
                 djvu_class = cuneiform_tag_to_djvu(node.tag)
 
     if not djvu_class:
@@ -478,4 +477,4 @@ __all__ = [
     'TEXT_DETAILS_LINE', 'TEXT_DETAILS_WORD', 'TEXT_DETAILS_CHARACTER'
 ]
 
-# vim:ts=4 sw=4 et
+# vim:ts=4 sts=4 sw=4 et
