@@ -1,6 +1,6 @@
 # encoding=UTF-8
 
-# Copyright © 2008, 2009, 2010, 2011, 2012 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2008-2015 Jakub Wilk <jwilk@jwilk.net>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -22,7 +22,7 @@ import subprocess
 # CalledProcessError, CalledProcessInterrupted
 # ============================================
 
-# Protect from scanadf[0] and possibly other brain-dead software that set
+# Protect from scanadf[0] and possibly other software that sets
 # SIGCHLD to SIG_IGN.
 # [0] https://bugs.debian.org/596232
 if os.name == 'posix':
@@ -38,12 +38,12 @@ def get_signal_names():
     try:
         if data['SIGABRT'] == data['SIGIOT']:
             del data['SIGIOT']
-    except KeyError:
+    except KeyError:  # <no-coverage>
         pass
     try:
         if data['SIGCHLD'] == data['SIGCLD']:
             del data['SIGCLD']
-    except KeyError:
+    except KeyError:  # <no-coverage>
         pass
     return dict((no, name) for name, no in data.iteritems())
 
@@ -59,7 +59,7 @@ class CalledProcessInterrupted(CalledProcessError):
 
     def __str__(self):
         signal_name = self._signal_names.get(self.args[1], self.args[1])
-        return 'Command %r was interrupted by signal %s' % (self.args[0], signal_name)
+        return 'Command {cmd!r} was interrupted by signal {sig}'.format(cmd=self.args[0], sig=signal_name)
 
 del get_signal_names
 
@@ -69,7 +69,7 @@ del get_signal_names
 def shell_escape(s, safe=re.compile('^[a-zA-Z0-9_+/=.,:%-]+$').match):
     if safe(s):
         return s
-    return "'%s'" % s.replace("'", r"'\''")
+    return "'{0}'".format(s.replace("'", r"'\''"))
 
 class Subprocess(subprocess.Popen):
 
@@ -81,9 +81,9 @@ class Subprocess(subprocess.Popen):
         # - but reset all other locale settings (which tend to break things).
         lc_ctype = env.get('LC_ALL') or env.get('LC_CTYPE') or env.get('LANG')
         env = dict(
-                (k, v)
-                for k, v in env.iteritems()
-                if not (k.startswith('LC_') or k in ('LANG', 'LANGUAGE'))
+            (k, v)
+            for k, v in env.iteritems()
+            if not (k.startswith('LC_') or k in ('LANG', 'LANGUAGE'))
         )
         if lc_ctype:
             env['LC_CTYPE'] = lc_ctype
@@ -104,7 +104,7 @@ class Subprocess(subprocess.Popen):
         self.__command = commandline[0]
         try:
             subprocess.Popen.__init__(self, *args, **kwargs)
-        except EnvironmentError, ex:
+        except EnvironmentError as ex:
             ex.filename = self.__command
             raise
 
@@ -133,4 +133,4 @@ __all__ = [
     'Subprocess', 'PIPE',
 ]
 
-# vim:ts=4 sw=4 et
+# vim:ts=4 sts=4 sw=4 et
