@@ -1,6 +1,6 @@
 # encoding=UTF-8
 
-# Copyright © 2008, 2009, 2010, 2011, 2012 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2008-2015 Jakub Wilk <jwilk@jwilk.net>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@ try:
     from djvu.dllpath import set_dll_search_path
 except ImportError:
     pass
-else:
+else:  # <no-coverage>
     set_dll_search_path()
 
 from . import utils
@@ -25,7 +25,7 @@ try:
     from djvu import const
     from djvu import decode
     from djvu import sexpr
-except ImportError, ex:
+except ImportError as ex:  # <no-coverage>
     utils.enhance_import_error(ex, 'python-djvulibre', 'python-djvu', 'http://jwilk.net/software/python-djvulibre')
     raise
 
@@ -187,6 +187,7 @@ def group_words(zones, details, word_break_iterator):
             Zone(zone.type, BBox(x0 + w * n // m, y0, x0 + w * (n + 1) // m, y1))
             for n, ch in enumerate(zone_text)
         ]
+        del x0, y0, x1, y1  # quieten pyflakes
     zones = split_zones
     del split_zones
     assert len(text) == len(zones)
@@ -201,7 +202,7 @@ def group_words(zones, details, word_break_iterator):
         for k in xrange(i, j):
             bbox.update(zones[k].bbox)
         last_word = Zone(type=const.TEXT_ZONE_WORD, bbox=bbox)
-        words += last_word,
+        words += [last_word]
         if details > TEXT_DETAILS_CHARACTER:
             last_word += [subtext]
         else:
@@ -213,4 +214,15 @@ def group_words(zones, details, word_break_iterator):
         i = j
     return words
 
-# vim:ts=4 sw=4 et
+try:
+    sexpr.Expression(0).as_string(escape_unicode=True)
+except TypeError:
+    # python-djvulibre << 0.4
+    def print_sexpr(expr, file, width=None):
+        return expr.print_into(file, width=width)
+else:
+    # python-djvulibre >= 0.4
+    def print_sexpr(expr, file, width=None):
+        return expr.print_into(file, width=width, escape_unicode=False)
+
+# vim:ts=4 sts=4 sw=4 et
