@@ -1,6 +1,6 @@
 # encoding=UTF-8
 
-# Copyright © 2010, 2011, 2013 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2010-2015 Jakub Wilk <jwilk@jwilk.net>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -11,16 +11,13 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 # General Public License for more details.
 
-from __future__ import with_statement
-
 import os
 import sys
 
 from tests.common import (
     assert_equal,
-    assert_false,
-    assert_true,
-    exception,
+    assert_raises,
+    assert_raises_regexp,
     interim,
 )
 
@@ -30,11 +27,7 @@ from lib.engines.cuneiform import (
 )
 
 here = os.path.dirname(__file__)
-try:
-    here = os.path.relpath(here)
-except AttributeError:
-    # Python 2.5. No big deal.
-    pass
+here = os.path.relpath(here)
 
 engine = None
 
@@ -57,7 +50,7 @@ class test_language():
         if ok:
             engine.check_language(lang)
         else:
-            with exception(lib.errors.MissingLanguagePack, regex='^language pack for the selected language (.+) is not available$'):
+            with assert_raises_regexp(lib.errors.MissingLanguagePack, '^language pack for the selected language (.+) is not available$'):
                 engine.check_language(lang)
 
     def test_has_language(self):
@@ -76,7 +69,7 @@ class test_language():
             assert_equal(args[2], lang1)
             raise EOFError
         with interim(lib.ipc, Subprocess=fake_subprocess):
-            with exception(EOFError, ''):
+            with assert_raises(EOFError):
                 with engine.recognize(sys.stdin, lang1):
                     pass
 
@@ -86,4 +79,4 @@ class test_language():
             if lang1 != lang2:
                 yield self._test_recognize, lang1, lang1
 
-# vim:ts=4 sw=4 et
+# vim:ts=4 sts=4 sw=4 et
