@@ -1,6 +1,6 @@
 # encoding=UTF-8
 
-# Copyright © 2010, 2011, 2013 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2010-2015 Jakub Wilk <jwilk@jwilk.net>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -11,18 +11,18 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 # General Public License for more details.
 
-from __future__ import with_statement
+from __future__ import print_function
 
 import os
 import signal
 import stat
 
 from tests.common import (
-    amended_environment,
     assert_equal,
     assert_false,
     assert_true,
-    exception,
+    assert_raises,
+    interim_environ,
 )
 
 from lib import ipc
@@ -48,7 +48,7 @@ class test_exceptions():
     def test_invalid_signo(self):
         # signal.NSIG is guaranteed not be a correct signal number
         ex = ipc.CalledProcessInterrupted(signal.NSIG, 'eggs')
-        assert_equal(str(ex), "Command 'eggs' was interrupted by signal %d" % signal.NSIG)
+        assert_equal(str(ex), "Command 'eggs' was interrupted by signal {0}".format(signal.NSIG))
         assert_false(ex.by_user)
 
 class test_wait():
@@ -59,14 +59,16 @@ class test_wait():
 
     def test1(self):
         child = ipc.Subprocess(['false'])
-        with exception(ipc.CalledProcessError, "Command 'false' returned non-zero exit status 1"):
+        with assert_raises(ipc.CalledProcessError) as ecm:
             child.wait()
+        assert_equal(str(ecm.exception), "Command 'false' returned non-zero exit status 1")
 
     def _test_signal(self, name):
-        child = ipc.Subprocess(['cat'], stdin=ipc.PIPE) # Any long-standing process would do.
+        child = ipc.Subprocess(['cat'], stdin=ipc.PIPE)  # Any long-standing process would do.
         os.kill(child.pid, getattr(signal, name))
-        with exception(ipc.CalledProcessInterrupted, "Command 'cat' was interrupted by signal " + name):
+        with assert_raises(ipc.CalledProcessInterrupted) as ecm:
             child.wait()
+        assert_equal(str(ecm.exception), "Command 'cat' was interrupted by signal " + name)
 
     def test_wait_signal(self):
         for name in 'SIGINT', 'SIGABRT', 'SIGSEGV':
@@ -77,7 +79,7 @@ class test_environment():
     # https://bugs.debian.org/594385
 
     def test1(self):
-        with amended_environment(ocrodjvu='42'):
+        with interim_environ(ocrodjvu='42'):
             child = ipc.Subprocess(
                 ['sh', '-c', 'printf $ocrodjvu'],
                 stdout=ipc.PIPE, stderr=ipc.PIPE,
@@ -87,7 +89,7 @@ class test_environment():
             assert_equal(stderr, '')
 
     def test2(self):
-        with amended_environment(ocrodjvu='42'):
+        with interim_environ(ocrodjvu='42'):
             child = ipc.Subprocess(
                 ['sh', '-c', 'printf $ocrodjvu'],
                 stdout=ipc.PIPE, stderr=ipc.PIPE,
@@ -98,7 +100,7 @@ class test_environment():
             assert_equal(stderr, '')
 
     def test3(self):
-        with amended_environment(ocrodjvu='42'):
+        with interim_environ(ocrodjvu='42'):
             child = ipc.Subprocess(
                 ['sh', '-c', 'printf $ocrodjvu'],
                 stdout=ipc.PIPE, stderr=ipc.PIPE,
@@ -114,12 +116,12 @@ class test_environment():
             command_name = temporary.name(dir=tmpdir)
             command_path = os.path.join(tmpdir, command_name)
             with open(command_path, 'wt') as file:
-                print >>file, '#!/bin/sh'
-                print >>file, 'printf 42'
+                print('#!/bin/sh', file=file)
+                print('printf 42', file=file)
             os.chmod(command_path, stat.S_IRWXU)
             path[:0] = [tmpdir]
             path = ':'.join(path)
-            with amended_environment(PATH=path):
+            with interim_environ(PATH=path):
                 child = ipc.Subprocess([command_name],
                     stdout=ipc.PIPE, stderr=ipc.PIPE,
                 )
@@ -156,15 +158,15 @@ class test_environment():
         assert_true(has_lang)
 
     def test_locale_lc_all(self):
-        with amended_environment(LC_ALL='en_US.UTF-8'):
+        with interim_environ(LC_ALL='en_US.UTF-8'):
             self._test_locale()
 
     def test_locale_lc_ctype(self):
-        with amended_environment(LC_ALL=None, LC_CTYPE='en_US.UTF-8'):
+        with interim_environ(LC_ALL=None, LC_CTYPE='en_US.UTF-8'):
             self._test_locale()
 
     def test_locale_lang(self):
-        with amended_environment(LC_ALL=None, LC_CTYPE=None, LANG='en_US.UTF-8'):
+        with interim_environ(LC_ALL=None, LC_CTYPE=None, LANG='en_US.UTF-8'):
             self._test_locale()
 
-# vim:ts=4 sw=4 et
+# vim:ts=4 sts=4 sw=4 et
